ML Plumber
===============

.. image:: https://github.com/ragrawal/mlplumber/workflows/Run%20Test/badge.svg

This is a collection of reciepes to deploy python based ML models in
production. These reciepes are mainly geared towards pipeline using
sklearn, sklearn-pandas, baikal, pandas, etc. Currently available
recieps are:

Change log:
-----------------

0.1.1:
+++++++++++++++++
    - Replaced tox with nox

Contribution Guide
----------------------





